==> google-cloud-container-2.1.0.tar.gz: google-cloud-container-2.1.0/google/cloud/container/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.container_v1.services.cluster_manager.async_client import (
    ClusterManagerAsyncClient,
)
from google.cloud.container_v1.services.cluster_manager.client import (
    ClusterManagerClient,
)
from google.cloud.container_v1.types.cluster_service import AcceleratorConfig
from google.cloud.container_v1.types.cluster_service import AddonsConfig
from google.cloud.container_v1.types.cluster_service import AuthenticatorGroupsConfig
from google.cloud.container_v1.types.cluster_service import AutoUpgradeOptions
from google.cloud.container_v1.types.cluster_service import (
    AutoprovisioningNodePoolDefaults,
)
from google.cloud.container_v1.types.cluster_service import BinaryAuthorization
from google.cloud.container_v1.types.cluster_service import CancelOperationRequest
from google.cloud.container_v1.types.cluster_service import ClientCertificateConfig
from google.cloud.container_v1.types.cluster_service import CloudRunConfig
from google.cloud.container_v1.types.cluster_service import Cluster
from google.cloud.container_v1.types.cluster_service import ClusterAutoscaling
from google.cloud.container_v1.types.cluster_service import ClusterUpdate
from google.cloud.container_v1.types.cluster_service import CompleteIPRotationRequest
from google.cloud.container_v1.types.cluster_service import CreateClusterRequest
from google.cloud.container_v1.types.cluster_service import CreateNodePoolRequest
from google.cloud.container_v1.types.cluster_service import DailyMaintenanceWindow
from google.cloud.container_v1.types.cluster_service import DatabaseEncryption
from google.cloud.container_v1.types.cluster_service import DeleteClusterRequest
from google.cloud.container_v1.types.cluster_service import DeleteNodePoolRequest
from google.cloud.container_v1.types.cluster_service import GetClusterRequest
from google.cloud.container_v1.types.cluster_service import GetNodePoolRequest
from google.cloud.container_v1.types.cluster_service import GetOperationRequest
from google.cloud.container_v1.types.cluster_service import GetServerConfigRequest
from google.cloud.container_v1.types.cluster_service import HorizontalPodAutoscaling
from google.cloud.container_v1.types.cluster_service import HttpLoadBalancing
from google.cloud.container_v1.types.cluster_service import IPAllocationPolicy
from google.cloud.container_v1.types.cluster_service import IntraNodeVisibilityConfig
from google.cloud.container_v1.types.cluster_service import KubernetesDashboard
from google.cloud.container_v1.types.cluster_service import LegacyAbac
from google.cloud.container_v1.types.cluster_service import ListClustersRequest
from google.cloud.container_v1.types.cluster_service import ListClustersResponse
from google.cloud.container_v1.types.cluster_service import ListNodePoolsRequest
from google.cloud.container_v1.types.cluster_service import ListNodePoolsResponse
from google.cloud.container_v1.types.cluster_service import ListOperationsRequest
from google.cloud.container_v1.types.cluster_service import ListOperationsResponse
from google.cloud.container_v1.types.cluster_service import ListUsableSubnetworksRequest
from google.cloud.container_v1.types.cluster_service import (
    ListUsableSubnetworksResponse,
)
from google.cloud.container_v1.types.cluster_service import MaintenancePolicy
from google.cloud.container_v1.types.cluster_service import MaintenanceWindow
from google.cloud.container_v1.types.cluster_service import MasterAuth
from google.cloud.container_v1.types.cluster_service import (
    MasterAuthorizedNetworksConfig,
)
from google.cloud.container_v1.types.cluster_service import MaxPodsConstraint
from google.cloud.container_v1.types.cluster_service import NetworkConfig
from google.cloud.container_v1.types.cluster_service import NetworkPolicy
from google.cloud.container_v1.types.cluster_service import NetworkPolicyConfig
from google.cloud.container_v1.types.cluster_service import NodeConfig
from google.cloud.container_v1.types.cluster_service import NodeManagement
from google.cloud.container_v1.types.cluster_service import NodePool
from google.cloud.container_v1.types.cluster_service import NodePoolAutoscaling
from google.cloud.container_v1.types.cluster_service import NodeTaint
from google.cloud.container_v1.types.cluster_service import Operation
from google.cloud.container_v1.types.cluster_service import PrivateClusterConfig
from google.cloud.container_v1.types.cluster_service import RecurringTimeWindow
from google.cloud.container_v1.types.cluster_service import ResourceLimit
from google.cloud.container_v1.types.cluster_service import ResourceUsageExportConfig
from google.cloud.container_v1.types.cluster_service import (
    RollbackNodePoolUpgradeRequest,
)
from google.cloud.container_v1.types.cluster_service import ServerConfig
from google.cloud.container_v1.types.cluster_service import SetAddonsConfigRequest
from google.cloud.container_v1.types.cluster_service import SetLabelsRequest
from google.cloud.container_v1.types.cluster_service import SetLegacyAbacRequest
from google.cloud.container_v1.types.cluster_service import SetLocationsRequest
from google.cloud.container_v1.types.cluster_service import SetLoggingServiceRequest
from google.cloud.container_v1.types.cluster_service import SetMaintenancePolicyRequest
from google.cloud.container_v1.types.cluster_service import SetMasterAuthRequest
from google.cloud.container_v1.types.cluster_service import SetMonitoringServiceRequest
from google.cloud.container_v1.types.cluster_service import SetNetworkPolicyRequest
from google.cloud.container_v1.types.cluster_service import (
    SetNodePoolAutoscalingRequest,
)
from google.cloud.container_v1.types.cluster_service import SetNodePoolManagementRequest
from google.cloud.container_v1.types.cluster_service import SetNodePoolSizeRequest
from google.cloud.container_v1.types.cluster_service import ShieldedInstanceConfig
from google.cloud.container_v1.types.cluster_service import StartIPRotationRequest
from google.cloud.container_v1.types.cluster_service import StatusCondition
from google.cloud.container_v1.types.cluster_service import TimeWindow
from google.cloud.container_v1.types.cluster_service import UpdateClusterRequest
from google.cloud.container_v1.types.cluster_service import UpdateMasterRequest
from google.cloud.container_v1.types.cluster_service import UpdateNodePoolRequest
from google.cloud.container_v1.types.cluster_service import UsableSubnetwork
from google.cloud.container_v1.types.cluster_service import (
    UsableSubnetworkSecondaryRange,
)
from google.cloud.container_v1.types.cluster_service import VerticalPodAutoscaling

__all__ = (
    "AcceleratorConfig",
    "AddonsConfig",
    "AuthenticatorGroupsConfig",
    "AutoUpgradeOptions",
    "AutoprovisioningNodePoolDefaults",
    "BinaryAuthorization",
    "CancelOperationRequest",
    "ClientCertificateConfig",
    "CloudRunConfig",
    "Cluster",
    "ClusterAutoscaling",
    "ClusterManagerAsyncClient",
    "ClusterManagerClient",
    "ClusterUpdate",
    "CompleteIPRotationRequest",
    "CreateClusterRequest",
    "CreateNodePoolRequest",
    "DailyMaintenanceWindow",
    "DatabaseEncryption",
    "DeleteClusterRequest",
    "DeleteNodePoolRequest",
    "GetClusterRequest",
    "GetNodePoolRequest",
    "GetOperationRequest",
    "GetServerConfigRequest",
    "HorizontalPodAutoscaling",
    "HttpLoadBalancing",
    "IPAllocationPolicy",
    "IntraNodeVisibilityConfig",
    "KubernetesDashboard",
    "LegacyAbac",
    "ListClustersRequest",
    "ListClustersResponse",
    "ListNodePoolsRequest",
    "ListNodePoolsResponse",
    "ListOperationsRequest",
    "ListOperationsResponse",
    "ListUsableSubnetworksRequest",
    "ListUsableSubnetworksResponse",
    "MaintenancePolicy",
    "MaintenanceWindow",
    "MasterAuth",
    "MasterAuthorizedNetworksConfig",
    "MaxPodsConstraint",
    "NetworkConfig",
    "NetworkPolicy",
    "NetworkPolicyConfig",
    "NodeConfig",
    "NodeManagement",
    "NodePool",
    "NodePoolAutoscaling",
    "NodeTaint",
    "Operation",
    "PrivateClusterConfig",
    "RecurringTimeWindow",
    "ResourceLimit",
    "ResourceUsageExportConfig",
    "RollbackNodePoolUpgradeRequest",
    "ServerConfig",
    "SetAddonsConfigRequest",
    "SetLabelsRequest",
    "SetLegacyAbacRequest",
    "SetLocationsRequest",
    "SetLoggingServiceRequest",
    "SetMaintenancePolicyRequest",
    "SetMasterAuthRequest",
    "SetMonitoringServiceRequest",
    "SetNetworkPolicyRequest",
    "SetNodePoolAutoscalingRequest",
    "SetNodePoolManagementRequest",
    "SetNodePoolSizeRequest",
    "ShieldedInstanceConfig",
    "StartIPRotationRequest",
    "StatusCondition",
    "TimeWindow",
    "UpdateClusterRequest",
    "UpdateMasterRequest",
    "UpdateNodePoolRequest",
    "UsableSubnetwork",
    "UsableSubnetworkSecondaryRange",
    "VerticalPodAutoscaling",
)

==> google-cloud-container-2.3.1.tar.gz: google-cloud-container-2.3.1/google/cloud/container/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.container_v1.services.cluster_manager.async_client import (
    ClusterManagerAsyncClient,
)
from google.cloud.container_v1.services.cluster_manager.client import (
    ClusterManagerClient,
)
from google.cloud.container_v1.types.cluster_service import AcceleratorConfig
from google.cloud.container_v1.types.cluster_service import AddonsConfig
from google.cloud.container_v1.types.cluster_service import AuthenticatorGroupsConfig
from google.cloud.container_v1.types.cluster_service import AutoUpgradeOptions
from google.cloud.container_v1.types.cluster_service import (
    AutoprovisioningNodePoolDefaults,
)
from google.cloud.container_v1.types.cluster_service import BinaryAuthorization
from google.cloud.container_v1.types.cluster_service import CancelOperationRequest
from google.cloud.container_v1.types.cluster_service import ClientCertificateConfig
from google.cloud.container_v1.types.cluster_service import CloudRunConfig
from google.cloud.container_v1.types.cluster_service import Cluster
from google.cloud.container_v1.types.cluster_service import ClusterAutoscaling
from google.cloud.container_v1.types.cluster_service import ClusterUpdate
from google.cloud.container_v1.types.cluster_service import CompleteIPRotationRequest
from google.cloud.container_v1.types.cluster_service import ConfigConnectorConfig
from google.cloud.container_v1.types.cluster_service import CreateClusterRequest
from google.cloud.container_v1.types.cluster_service import CreateNodePoolRequest
from google.cloud.container_v1.types.cluster_service import DailyMaintenanceWindow
from google.cloud.container_v1.types.cluster_service import DatabaseEncryption
from google.cloud.container_v1.types.cluster_service import DefaultSnatStatus
from google.cloud.container_v1.types.cluster_service import DeleteClusterRequest
from google.cloud.container_v1.types.cluster_service import DeleteNodePoolRequest
from google.cloud.container_v1.types.cluster_service import DnsCacheConfig
from google.cloud.container_v1.types.cluster_service import GetClusterRequest
from google.cloud.container_v1.types.cluster_service import GetJSONWebKeysRequest
from google.cloud.container_v1.types.cluster_service import GetJSONWebKeysResponse
from google.cloud.container_v1.types.cluster_service import GetNodePoolRequest
from google.cloud.container_v1.types.cluster_service import GetOpenIDConfigRequest
from google.cloud.container_v1.types.cluster_service import GetOpenIDConfigResponse
from google.cloud.container_v1.types.cluster_service import GetOperationRequest
from google.cloud.container_v1.types.cluster_service import GetServerConfigRequest
from google.cloud.container_v1.types.cluster_service import HorizontalPodAutoscaling
from google.cloud.container_v1.types.cluster_service import HttpLoadBalancing
from google.cloud.container_v1.types.cluster_service import IPAllocationPolicy
from google.cloud.container_v1.types.cluster_service import IntraNodeVisibilityConfig
from google.cloud.container_v1.types.cluster_service import Jwk
from google.cloud.container_v1.types.cluster_service import KubernetesDashboard
from google.cloud.container_v1.types.cluster_service import LegacyAbac
from google.cloud.container_v1.types.cluster_service import ListClustersRequest
from google.cloud.container_v1.types.cluster_service import ListClustersResponse
from google.cloud.container_v1.types.cluster_service import ListNodePoolsRequest
from google.cloud.container_v1.types.cluster_service import ListNodePoolsResponse
from google.cloud.container_v1.types.cluster_service import ListOperationsRequest
from google.cloud.container_v1.types.cluster_service import ListOperationsResponse
from google.cloud.container_v1.types.cluster_service import ListUsableSubnetworksRequest
from google.cloud.container_v1.types.cluster_service import (
    ListUsableSubnetworksResponse,
)
from google.cloud.container_v1.types.cluster_service import MaintenancePolicy
from google.cloud.container_v1.types.cluster_service import MaintenanceWindow
from google.cloud.container_v1.types.cluster_service import MasterAuth
from google.cloud.container_v1.types.cluster_service import (
    MasterAuthorizedNetworksConfig,
)
from google.cloud.container_v1.types.cluster_service import MaxPodsConstraint
from google.cloud.container_v1.types.cluster_service import NetworkConfig
from google.cloud.container_v1.types.cluster_service import NetworkPolicy
from google.cloud.container_v1.types.cluster_service import NetworkPolicyConfig
from google.cloud.container_v1.types.cluster_service import NodeConfig
from google.cloud.container_v1.types.cluster_service import NodeManagement
from google.cloud.container_v1.types.cluster_service import NodePool
from google.cloud.container_v1.types.cluster_service import NodePoolAutoscaling
from google.cloud.container_v1.types.cluster_service import NodeTaint
from google.cloud.container_v1.types.cluster_service import Operation
from google.cloud.container_v1.types.cluster_service import OperationProgress
from google.cloud.container_v1.types.cluster_service import PrivateClusterConfig
from google.cloud.container_v1.types.cluster_service import (
    PrivateClusterMasterGlobalAccessConfig,
)
from google.cloud.container_v1.types.cluster_service import RecurringTimeWindow
from google.cloud.container_v1.types.cluster_service import ReleaseChannel
from google.cloud.container_v1.types.cluster_service import ReservationAffinity
from google.cloud.container_v1.types.cluster_service import ResourceLimit
from google.cloud.container_v1.types.cluster_service import ResourceUsageExportConfig
from google.cloud.container_v1.types.cluster_service import (
    RollbackNodePoolUpgradeRequest,
)
from google.cloud.container_v1.types.cluster_service import SandboxConfig
from google.cloud.container_v1.types.cluster_service import ServerConfig
from google.cloud.container_v1.types.cluster_service import SetAddonsConfigRequest
from google.cloud.container_v1.types.cluster_service import SetLabelsRequest
from google.cloud.container_v1.types.cluster_service import SetLegacyAbacRequest
from google.cloud.container_v1.types.cluster_service import SetLocationsRequest
from google.cloud.container_v1.types.cluster_service import SetLoggingServiceRequest
from google.cloud.container_v1.types.cluster_service import SetMaintenancePolicyRequest
from google.cloud.container_v1.types.cluster_service import SetMasterAuthRequest
from google.cloud.container_v1.types.cluster_service import SetMonitoringServiceRequest
from google.cloud.container_v1.types.cluster_service import SetNetworkPolicyRequest
from google.cloud.container_v1.types.cluster_service import (
    SetNodePoolAutoscalingRequest,
)
from google.cloud.container_v1.types.cluster_service import SetNodePoolManagementRequest
from google.cloud.container_v1.types.cluster_service import SetNodePoolSizeRequest
from google.cloud.container_v1.types.cluster_service import ShieldedInstanceConfig
from google.cloud.container_v1.types.cluster_service import ShieldedNodes
from google.cloud.container_v1.types.cluster_service import StartIPRotationRequest
from google.cloud.container_v1.types.cluster_service import StatusCondition
from google.cloud.container_v1.types.cluster_service import TimeWindow
from google.cloud.container_v1.types.cluster_service import UpdateClusterRequest
from google.cloud.container_v1.types.cluster_service import UpdateMasterRequest
from google.cloud.container_v1.types.cluster_service import UpdateNodePoolRequest
from google.cloud.container_v1.types.cluster_service import UsableSubnetwork
from google.cloud.container_v1.types.cluster_service import (
    UsableSubnetworkSecondaryRange,
)
from google.cloud.container_v1.types.cluster_service import VerticalPodAutoscaling
from google.cloud.container_v1.types.cluster_service import WorkloadIdentityConfig
from google.cloud.container_v1.types.cluster_service import WorkloadMetadataConfig

__all__ = (
    "AcceleratorConfig",
    "AddonsConfig",
    "AuthenticatorGroupsConfig",
    "AutoUpgradeOptions",
    "AutoprovisioningNodePoolDefaults",
    "BinaryAuthorization",
    "CancelOperationRequest",
    "ClientCertificateConfig",
    "CloudRunConfig",
    "Cluster",
    "ClusterAutoscaling",
    "ClusterManagerAsyncClient",
    "ClusterManagerClient",
    "ClusterUpdate",
    "CompleteIPRotationRequest",
    "ConfigConnectorConfig",
    "CreateClusterRequest",
    "CreateNodePoolRequest",
    "DailyMaintenanceWindow",
    "DatabaseEncryption",
    "DefaultSnatStatus",
    "DeleteClusterRequest",
    "DeleteNodePoolRequest",
    "DnsCacheConfig",
    "GetClusterRequest",
    "GetJSONWebKeysRequest",
    "GetJSONWebKeysResponse",
    "GetNodePoolRequest",
    "GetOpenIDConfigRequest",
    "GetOpenIDConfigResponse",
    "GetOperationRequest",
    "GetServerConfigRequest",
    "HorizontalPodAutoscaling",
    "HttpLoadBalancing",
    "IPAllocationPolicy",
    "IntraNodeVisibilityConfig",
    "Jwk",
    "KubernetesDashboard",
    "LegacyAbac",
    "ListClustersRequest",
    "ListClustersResponse",
    "ListNodePoolsRequest",
    "ListNodePoolsResponse",
    "ListOperationsRequest",
    "ListOperationsResponse",
    "ListUsableSubnetworksRequest",
    "ListUsableSubnetworksResponse",
    "MaintenancePolicy",
    "MaintenanceWindow",
    "MasterAuth",
    "MasterAuthorizedNetworksConfig",
    "MaxPodsConstraint",
    "NetworkConfig",
    "NetworkPolicy",
    "NetworkPolicyConfig",
    "NodeConfig",
    "NodeManagement",
    "NodePool",
    "NodePoolAutoscaling",
    "NodeTaint",
    "Operation",
    "OperationProgress",
    "PrivateClusterConfig",
    "PrivateClusterMasterGlobalAccessConfig",
    "RecurringTimeWindow",
    "ReleaseChannel",
    "ReservationAffinity",
    "ResourceLimit",
    "ResourceUsageExportConfig",
    "RollbackNodePoolUpgradeRequest",
    "SandboxConfig",
    "ServerConfig",
    "SetAddonsConfigRequest",
    "SetLabelsRequest",
    "SetLegacyAbacRequest",
    "SetLocationsRequest",
    "SetLoggingServiceRequest",
    "SetMaintenancePolicyRequest",
    "SetMasterAuthRequest",
    "SetMonitoringServiceRequest",
    "SetNetworkPolicyRequest",
    "SetNodePoolAutoscalingRequest",
    "SetNodePoolManagementRequest",
    "SetNodePoolSizeRequest",
    "ShieldedInstanceConfig",
    "ShieldedNodes",
    "StartIPRotationRequest",
    "StatusCondition",
    "TimeWindow",
    "UpdateClusterRequest",
    "UpdateMasterRequest",
    "UpdateNodePoolRequest",
    "UsableSubnetwork",
    "UsableSubnetworkSecondaryRange",
    "VerticalPodAutoscaling",
    "WorkloadIdentityConfig",
    "WorkloadMetadataConfig",
)
